import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { Suspense, lazy } from 'react';
import { styled, Box, createTheme, ThemeProvider, Link, Typography, Icon } from '@mui/material';
import { theme, Form, FormField, InputLabel, CheckboxInput, PasswordInput, Button, TextInput, SetupCardInfoRow, SetupCardAccordion, SetupCardContent, SetupCardTask as SetupCardTask$1 } from '@moderntribe/wme-ui';
import { HashRouter, Routes, Route, useNavigate } from 'react-router-dom';
import { __ } from '@wordpress/i18n';
import { useState } from '@wordpress/element';
import { CheckCircle } from '@mui/icons-material';
import { isValidUrl } from '@moderntribe/wme-utils';

const StyledLoaderContainer = styled(Box, {
    name: 'WmeLoader',
    slot: 'Root',
    shouldForwardProp: (prop) => prop !== 'fullscreen',
})(({ fullscreen }) => ({
    textAlign: 'center',
    ...(fullscreen && {
        display: 'grid',
        placeItems: 'center',
        position: 'absolute',
        height: '100vh',
        width: '100%',
    })
}));
const StyledLoader = styled(Box, {
    name: 'WmeLoader',
    slot: 'Loader',
})(() => ({
    '@keyframes wme-ball-loader': {
        '33%': {
            transform: 'translateY(24px)'
        },
        '66%': {
            transform: 'translateY(-24px)'
        },
        '100%': {
            transform: 'translateY(0)'
        }
    },
    '& > div:nth-of-type(1)': {
        animation: 'wme-ball-loader 0.7s -0.14s infinite ease-in-out',
    },
    '& > div:nth-of-type(2)': {
        animation: 'wme-ball-loader 0.7s -0.07s infinite ease-in-out',
    },
    '& > div:nth-of-type(3)': {
        animation: 'wme-ball-loader 0.7s 0s infinite ease-in-out',
    }
}));
const StyledLoaderBall = styled(Box, {
    name: 'WmeLoader',
    slot: 'Ball',
})(({ theme }) => ({
    backgroundColor: theme.palette.border.ui,
    width: '15px',
    height: '15px',
    borderRadius: '50%',
    margin: '5px',
    display: 'inline-block',
}));
function Loading(props) {
    return (jsx(StyledLoaderContainer, { ...props, children: jsxs(StyledLoader, { children: [jsx(StyledLoaderBall, {}), jsx(StyledLoaderBall, {}), jsx(StyledLoaderBall, {})] }) }));
}

const Loadable = (Component) => (props) => {
    const { fullscreen, } = props;
    return (jsx(Suspense, { fallback: jsx(Loading, { fullscreen: fullscreen }), children: jsx(Component, { ...props }) }));
};

const SetupScreen$2 = Loadable(lazy(() => Promise.resolve().then(function () { return SetupScreen$1; })));
const siteSettingsTheme = createTheme(theme);
const SiteSettings = () => (jsx(ThemeProvider, { theme: siteSettingsTheme, children: jsx(HashRouter, { children: jsx(Routes, { children: jsx(Route, { path: "/", element: jsx(SetupScreen$2, { fullscreen: true }) }) }) }) }));

function getPasswordStrength(password) {
    if (password.length && password.length <= 6) {
        return 'weak';
    }
    const strength = window.wp.passwordStrength.meter(password, [], password);
    switch (strength) {
        case 1:
        case 2:
            return { label: 'weak', color: 'error' };
        case 3:
            return { label: 'medium', color: 'warning' };
        case 4:
            return { label: 'strong', color: 'success' };
        default:
            return { label: 'weak', color: 'error' };
    }
}

const SITE_SETTINGS = window?.site_settings;
const ASSETS_URL = SITE_SETTINGS?.assets_url;
const IMAGE_DIR = `${ASSETS_URL}images/`;
const CARDS = SITE_SETTINGS?.cards || [];
SITE_SETTINGS?.wizards || {};
SITE_SETTINGS.wizards.golive;
SITE_SETTINGS.support_url;
const SITE_DOMAIN_DATA = {
    screen: {
        title: __('Site Set Up', 'moderntribe-sitebuilder'),
    },
    goLiveStatus: {
        manage: __('Manage', 'moderntribe-sitebuilder'),
        statusMessage: __('Your site domain is', 'moderntribe-sitebuilder'),
        tryAgain: __('Try Again', 'moderntribe-sitebuilder'),
        verifyMsgPart1: __('We were unable to verify', 'moderntribe-sitebuilder'),
        verifyMsgPart2: __('Try again in 8-12 hrs after your last attempt.', 'moderntribe-sitebuilder'),
    },
    lookAndFeelFooter: {
        change: __('Change', 'moderntribe-sitebuilder'),
    },
    goLiveProviderText: {
        getDomain: __('Get My Domain', 'moderntribe-sitebuilder'),
        haveDomain: __('I\'ve Got My Domain', 'moderntribe-sitebuilder'),
        checkout: __('Checkout', 'moderntribe-sitebuilder'),
        continueStr: __('Continue', 'moderntribe-sitebuilder'),
        errorMessage: __('There was an error while updating your site\'s domain.', 'moderntribe-sitebuilder'),
        errorMessageVerification: __('There was an error while verifying your site\'s domain.', 'moderntribe-sitebuilder'),
        errorNotPointed: __('This domain is not pointing to your website.', 'moderntribe-sitebuilder'),
        errorNotRegistered: __('This domain is not registered.', 'moderntribe-sitebuilder'),
        errorGeneral: __('We\'re unable to connect your domain.', 'moderntribe-sitebuilder'),
    },
    findDomain: {
        title: __('Find the perfect domain.', 'moderntribe-sitebuilder'),
        description: __('Enter the domain name you want your store to have, and we\'ll see if it\'s available. If it isn\'t, we\'ll make suggestions about ones that are.', 'moderntribe-sitebuilder'),
        defaultError: __('Something went wrong, please try again', 'moderntribe-sitebuilder')
    },
    verifyDomain: {
        screenTitle: __('Verify your domain', 'moderntribe-sitebuilder'),
        screenDescription: __('We\'ll verify your domain and get it ready to use. This can take a while, but don\'t worry - we\'ll walk you through it.', 'moderntribe-sitebuilder'),
        screenNotice: __('If you\'re using a subdomain (ex: store.example.com), please stop here and reach out to support at', 'moderntribe-sitebuilder'),
        goLiveLabelText: __('Enter the domain you want to connect', 'moderntribe-sitebuilder'),
        goLivePlaceholderText: __('yourdomain.com', 'moderntribe-sitebuilder'),
        errorDomainFormat: __('The domain entered does not appear to be a valid format.', 'moderntribe-sitebuilder'),
    },
    updateSiteUrl: {
        screenTitle: __('You\'re ready to go live with', 'moderntribe-sitebuilder'),
        screenDescription: __('Once we begin, this process may take a few minutes. When the process is complete, you will need to log in again on the new live domain.', 'moderntribe-sitebuilder'),
        descriptionProcessing: __('This process will take a few minutes. You\'ll be logged out when it completes and will need to log in again on your new domain.', 'moderntribe-sitebuilder'),
        launchImgAltText: __('Go live rocket', 'moderntribe-sitebuilder'),
        loginUrlLabelText: __('Copy Your New Login URL', 'moderntribe-sitebuilder'),
        loginUrlHelperText: __('Copy and save this URL. Once your domain is connected you\'ll need it to login.', 'moderntribe-sitebuilder')
    },
    connectWithNexcess: {
        screenTitle: __('Good choice! We’ll need to connect to your Nexcess account.', 'moderntribe-sitebuilder'),
        screenDescription: __('We\'ll make sure your chosen domain is managed by your Nexcess account. Once connected, we\'ll navigate you back here to complete the process.', 'moderntribe-sitebuilder'),
    },
    claimYourDomain: {
        screenTitle: __('is all yours!', 'moderntribe-sitebuilder'),
        screenDescription: __('We need a little time to update the entire internet about your purchase. You\'ll be able to connect your domain when we\'re done. This typically takes an hour but can take up to 8 hours to complete.', 'moderntribe-sitebuilder'),
    },
    errorDomainGeneral: {
        accountContent: __('It looks like we\'re having trouble connecting your domain.', 'moderntribe-sitebuilder'),
        accountCta: __('Contact Support', 'moderntribe-sitebuilder')
    },
    errorDomainNotRegistered: {
        registerDomainContent: __('It looks like this domain is not registered. Don\'t worry, we can help you secure this domain for your Store. Nexcess helps you find, create and own your perfect domain. It’s so easy, even we could do it. Once you\'ve got your domain, come back here and select "I\'ve Got My Domain".', 'moderntribe-sitebuilder'),
        registerDomainCtaPart1: __('Purchase', 'moderntribe-sitebuilder'),
        registerDomainCtaPart2: __('With Nexcess', 'moderntribe-sitebuilder')
    },
    errorDomainRegisteredNotPointing: {
        helpHeadlinePart1: __('1. Enter Name Servers', 'moderntribe-sitebuilder'),
        helpHeadlinePart2: __('2. Retry your connection', 'moderntribe-sitebuilder'),
        helpHeadlinePart3: __('3. Still not working?', 'moderntribe-sitebuilder'),
        helpContentPart1: __('Log in to your domain registrar (the site where you bought your domain) and change the nameservers to the following:', 'moderntribe-sitebuilder'),
        helpContentPart1a: __('If you don\'t know how to do this, your registrar\'s customer support team can help!', 'moderntribe-sitebuilder'),
        helpContentPart1b: __('Advanced users only: If you\'d prefer to point A records or CNAME records to your StoreBuilder site, you can log into the Nexcess Client Portal to find the settings for your site.', 'moderntribe-sitebuilder'),
        helpContentPart1c: __('Learn more about connecting a domain.', 'moderntribe-sitebuilder'),
        helpContentPart2: __('Once you\'ve pointed your Name Servers at Nexcess you can retry your connection. It can take up to 48 hours for this to work.', 'moderntribe-sitebuilder'),
        helpContentPart3: __('This can take awhile, depending on your provider. If it\'s been 48 hours since you added your nameservers, contact StoreBuilder support for further assistance. ', 'moderntribe-sitebuilder'),
        retryConnection: __('Retry connection', 'moderntribe-sitebuilder'),
        advancedLabelPart1: __('Advanced:', 'moderntribe-sitebuilder'),
        advancedLabelPart2: __('Skip verification', 'moderntribe-sitebuilder'),
        advancedContentPart1: __('By default, we check that the appropriate DNS records are set before changing your domain. If you\'re behind a proxy or are using another more advanced DNS technique, you may wish to skip this validation.', 'moderntribe-sitebuilder'),
        advancedContentPart2: __('Your site may become inaccessible if its DNS records are invalid, so please double-check your DNS configuration before continuing.', 'moderntribe-sitebuilder'),
        advancedContentPart3: __('If anything does go wrong, please reach out to support and we\'ll get you up and running!', 'moderntribe-sitebuilder'),
    },
    successDomainConnected: {
        statusSuccessPart1: __('Your domain is ready to connect!', 'moderntribe-sitebuilder'),
        statusSuccessPart2: __('Continue and we\'ll do all the work of updating your site to use your custom domain.', 'moderntribe-sitebuilder'),
        statusSuccessNote: __('This process may take a few minutes, after which you will need to log in again on the new live domain.', 'moderntribe-sitebuilder')
    },
    skipVerificationWarning: {
        warningHeadline: __('Skipping domain verification is an advanced step.', 'moderntribe-sitebuilder'),
        message1: __('Your site may become inaccessible if its domain records are invalid, so please double-check your configuration before continuing.', 'moderntribe-sitebuilder'),
        message2: __('If anything does go wrong, please reach out to support and we\'ll get you up and running!', 'moderntribe-sitebuilder'),
        continueButton: __('Continue without verification', 'moderntribe-sitebuilder'),
        nevermind: __('Do not skip verification', 'moderntribe-sitebuilder')
    },
    domainItems: {
        taken: __('Taken', 'moderntribe-sitebuilder'),
        selected: __('Selected', 'moderntribe-sitebuilder'),
        available: __('Available', 'moderntribe-sitebuilder'),
        unavailable: __('Unavailable', 'moderntribe-sitebuilder'),
    }
};

const PasswordWrapper = styled(Box)(({ theme }) => ({
    display: 'flex',
    alignItems: 'flex-start',
    gap: theme.spacing(1),
    '& .MuiInputBase-root': {
        minWidth: '415px',
    },
}));
const SiteVisibility = () => {
    const [visibilityValues, setVisibilityValues] = useState({
        hideSearchEngines: false,
        restrictAccess: false,
        password: '',
    });
    const [passwordStrength, setPasswordStrength] = useState();
    const handleChange = (event) => {
        setVisibilityValues({
            ...visibilityValues,
            [event.target.name]: event.target.type === 'checkbox' ? event.target.checked : event.target.value
        });
    };
    const handlePasswordChange = (event) => {
        const strength = getPasswordStrength(event.target.value);
        setPasswordStrength(strength);
        setVisibilityValues({ ...visibilityValues, password: event.target.value });
    };
    return (jsxs(Form, { children: [jsx(FormField, { field: jsx(InputLabel, { control: jsx(CheckboxInput, { checked: visibilityValues.hideSearchEngines, onChange: handleChange, name: "hideSearchEngines" }), label: __('Hide my sites from search engines, and whatever else.', 'moderntribe-sitebuilder') }) }), jsx(FormField, { field: jsx(InputLabel, { control: jsx(CheckboxInput, { checked: visibilityValues.restrictAccess, onChange: handleChange, name: "restrictAccess" }), label: __('Restrict access to visitors with the password.', 'moderntribe-sitebuilder'), checked: visibilityValues.restrictAccess }) }), visibilityValues.restrictAccess && (jsx(Fragment, { children: jsxs(PasswordWrapper, { mt: 2, mb: 3, children: [jsx(FormField, { field: jsx(PasswordInput, { name: "password", value: visibilityValues.password, chipColor: passwordStrength?.color, chipLabel: passwordStrength?.label, onChange: handlePasswordChange }), label: __('Password', 'moderntribe-sitebuilder'), helperText: __('Users will be asked for this password when accessing your site.', 'moderntribe-sitebuilder') }), jsx(Button, { variant: "contained", sx: { marginTop: '26px' }, children: __('Save', 'moderntribe-sitebuilder') })] }) }))] }));
};

const StyledFormField = styled(FormField)(({ theme }) => ({
    marginBottom: theme.spacing(2),
    '& .MuiInputBase-root': {
        width: '100%',
    }
}));
const GoogleAnalytics = () => {
    const [analyticsScript, setAnalyticsScript] = useState('');
    const handleChange = (event) => {
        setAnalyticsScript(event.target.value);
    };
    return (jsxs(Form, { children: [jsx(StyledFormField, { label: jsxs(Fragment, { children: [__('Google Analytics Code', 'moderntribe-sitebuilder'), ' ', jsx(Link, { href: "/", target: "_blank", rel: "noopener", children: __('(How do I set this up?)', 'moderntribe-sitebuilder') })] }), field: jsx(TextInput, { value: analyticsScript, onChange: handleChange, name: "analyticsScript", multiline: true, minRows: 5, placeholder: __('Paste your code from Google here', 'moderntribe-sitebuilder') }) }), jsx(Button, { variant: "contained", color: "primary", children: __('Save', 'moderntribe-sitebuilder') })] }));
};

const { goLiveStatus } = SITE_DOMAIN_DATA;
const iconSx = {
    fontSize: '1rem',
    lineHeight: 1,
    marginRight: '4px',
};
const StatusWrapper = ({ children }) => (jsx(Box, { component: "span", sx: { display: 'flex', alignItems: 'center' }, children: children }));
const StandardStatus = ({ domain, completed }) => (jsxs(StatusWrapper, { children: [completed && jsx(CheckCircle, { color: "success", sx: iconSx }), jsx(Typography, { component: "span", variant: "body2", mr: 0.5, color: "#666666", children: `${goLiveStatus.statusMessage} ` }), jsx(Typography, { component: "span", variant: "body2", fontWeight: 600, children: domain })] }));
const SiteDomain = (props) => {
    const { completed = false } = props;
    const domain = SITE_SETTINGS.site_url.replace(/^https?:\/\//, '');
    return (jsx(Fragment, { children: jsx(SetupCardInfoRow, { sx: { mb: 3 }, primary: jsx(StandardStatus, { domain: domain, completed: completed }) }) }));
};

const Container = styled(Box)(({ theme }) => ({
    maxWidth: theme.spacing(100),
    margin: `${theme.spacing(5)} auto`,
}));
const SetupCards = () => {
    return (jsx(Container, { children: CARDS.map((card) => {
            return (jsx(SetupCardAccordion, { id: card.id, header: card.title, subHeader: card.intro, chipText: card.chipText, chipBackground: card.chipBackground, children: jsxs(SetupCardContent, { children: [((card.id === 'site-visibility') && jsx(SiteVisibility, {})) ||
                            ((card.id === 'google-analytics') && jsx(GoogleAnalytics, {})) ||
                            ((card.id === 'launch-domain') && jsx(SiteDomain, {})) ||
                            jsx(Fragment, {}), jsx(SetupCardTasks, { rows: card.rows })] }) }, card.id));
        }) }));
};

const SetupCardTasks = (props) => {
    const { rows } = props;
    return (jsx(Fragment, { children: rows?.map((row) => {
            return jsx(SetupCardTask, { ...row }, row.id);
        }) }));
};

const getAvatarProps = (props) => {
    if (!props?.icon) {
        return {};
    }
    return {
        alt: props?.title,
        src: `${IMAGE_DIR + props.icon}`,
        width: '100%',
    };
};
const SetupCardTask = (props) => {
    const { url, target, wizardHash, ...rest } = props;
    const avatarProps = getAvatarProps(props);
    const navigate = useNavigate();
    const validUrl = url && isValidUrl(url);
    const handleOnClick = () => {
        if (wizardHash) {
            navigate(wizardHash);
        }
    };
    return jsx(SetupCardTask$1, { ...rest, onClick: !validUrl && wizardHash ? handleOnClick : undefined, href: validUrl ? url : undefined, target: validUrl ? target : undefined, icon: Object.keys(avatarProps).length > 0 && (jsx(Icon, { children: jsx("img", { ...avatarProps, alt: "icon" }) })) });
};

const SetupScreen = () => {
    return (jsxs(Box, { pt: 4, pl: '12px', pr: 4, children: [jsx(Typography, { variant: "h3", textAlign: "center", children: __('Site Settings', 'moderntribe-sitebuilder') }), jsx(SetupCards, {})] }));
};

var SetupScreen$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': SetupScreen
});

export { SiteSettings as default };
//# sourceMappingURL=index.js.map
